load

Macro load 

macro_rules! load {
    ($component:expr) => { ... };
}
Marks a route component as keep-alive.

Keep-alive route components are rendered inside the router outlet even when inactive. The inactive wrapper uses display: none, so it does not consume layout space, but the already spawned widget tree can be reused instantly when the route becomes active again.